@@ -8,6 +8,7 @@
 
 import argparse
 import contextlib
+import json
 import logging
 from pathlib import Path
 import shlex
@@ -23,6 +24,7 @@ from tuxrun.requests import requests_get
 from tuxrun.runtimes import Runtime
 import tuxrun.templates as templates
 from tuxrun.tuxmake import TuxMakeBuild
+from tuxrun.results import Results
 from tuxrun.utils import TTYProgressIndicator
 from tuxrun.writer import Writer
 from tuxrun.yaml import yaml_load
@@ -61,6 +63,16 @@ def pathurlnone(string):
     return f"file://{path.expanduser().resolve()}"
 
 
+def pathnone(string):
+    if string is None:
+        return None
+
+    path = Path(string)
+    if not path.exists():
+        raise argparse.ArgumentTypeError(f"{path} no such file or directory")
+    return path.expanduser().resolve()
+
+
 def tuxmake_directory(s):
     try:
         return TuxMakeBuild(s)
@@ -223,8 +235,12 @@ def setup_parser() -> argparse.ArgumentParser:
     )
 
     group = parser.add_argument_group("configuration files")
-    group.add_argument("--device-dict", default=None, help="Device configuration")
-    group.add_argument("--definition", default=None, help="Job definition")
+    group.add_argument(
+        "--device-dict", default=None, type=pathnone, help="Device configuration"
+    )
+    group.add_argument(
+        "--definition", default=None, type=pathnone, help="Job definition"
+    )
 
     group = parser.add_argument_group("runtime")
     group.add_argument(
@@ -240,8 +256,11 @@ def setup_parser() -> argparse.ArgumentParser:
         help="Image to use",
     )
 
-    group = parser.add_argument_group("logging")
+    group = parser.add_argument_group("output")
     group.add_argument("--log-file", default=None, type=Path, help="Store logs to file")
+    group.add_argument(
+        "--results", default=None, type=Path, help="Save test results to file (JSON)"
+    )
 
     group = parser.add_argument_group("debugging")
     group.add_argument(
@@ -395,14 +414,18 @@ def run(options, tmpdir: Path) -> int:
         LOG.debug("Pre run command")
         runtime.pre_run(tmpdir)
 
+    results = Results()
     # Start the writer (stderr or log-file)
     with Writer(options.log_file) as writer:
         # Start the runtime
         with runtime.run(args):
             for line in runtime.lines():
                 writer.write(line)
+                results.parse(line)
     runtime.post_run()
-    return runtime.ret()
+    if options.results:
+        options.results.write_text(json.dumps(results.data))
+    return max([runtime.ret(), results.ret()])
 
 
 def main() -> int:
